//########################################################################
//  Paper Title: Causally Evaluating Selection: Biological, 		
//               Behavioral and Institutional Effects on 
//               the Kidney Transplant Waitlist
//
//  Purpose: Generate data from DDC model for figures and
//           results in Appendix: Dynamic discrete choice model of candidate behavior
//                                                                    
//  Author: Stephen Kastoryano                                        
//  Date  : 20 June 2023
//  Ox version: 9
//
//  input:  None
//
//  output: "DGPsampleER.m", "DGPsampleER_min.m" - for dgpKidneyExp_2024.R 	
//          "DGPz1c.m","DGPz1S.m","DGPz1Sc.m", "DGPz0cER.m","DGPz0SER.m","DGPz0ScER.m",
//          "DGPz1c_min.m","DGPz1S.m","DGPz1Sc.m", "DGPz0cER.m","DGPz0SER.m","DGPz0ScER.m" - for DGPsimVal_2024.R    
//
//
// Instructions: Run twice, once for positive treamtent effect, setting nega=0 on line 432 
//               and once with with negative treatment effect, setting nega=1 on line 432
//                                                                    
//########################################################################



#include <oxfloat.h> 
#include <oxstd.h>
#import <maximize>
#include <oxprob.h>

decl sim;



dgpS(obs,vPrS,iTbar)
{
	decl  i,j,iPrS,idurS,vdurS;

	vdurS=zeros(obs,1);
	
	for(i=0;i<obs;++i)
	{
		iPrS= vPrS[i];	 //probability of treatment
		j=1;
		idurS=1;
        while (idurS .!= j-1)
        {
			idurS=j*(ranbinomial(1,1,1,iPrS) .==1);	 //random draw from binomial distribution
			idurS=idurS.*(idurS .<= iTbar+1) + (iTbar+1).*(idurS .== 0);
            ++j;						
        }
		vdurS[i]=j-1;
		//println("vdurS[i] =",j-1);
	 }

	 return vdurS;	   //return vector of potential treatment outcomes
}

V0(W0old, param, A,E, oututil, WSres, PrS)	 //reservation offer before treatment
{
	/******************************/
 	decl rho, sigU0, sigU1, sigW, BaW,BeW, BdW , BaC,BeC, BdC, BaL,BeL, BdL ;

	rho=param[0];             //Discount rate such that 1/rho~=0.99
	sigU0=param[1];				//standard deviation of U0 random utility shock when no exit 
	sigU1=param[2];				//standard deviation of U1 random utility shock when exit 
	sigW=param[3];					//standard deviation of U0 w offer
	BaW=param[4];                  //ability parameter on w offer
	BeW=param[5];                  //effort parameter on w offer
	BdW=param[6];                  //treatment parameter on w offer
	BaC=param[7];                  //ability parameter on search cost
	BeC=param[8];                  //effort parameter on search cost
	BdC=param[9];                  //treatment parameter on search cost
	BaL=param[10];                  //ability parameter on offer rate lambda
	BeL=param[11];                  //effort parameter on offer	rate lambda
	BdL=param[12];                  //treatment parameter on offer rate lambda
	/******************************/

	decl  vW0,vW1,vW0new,vW1new,veps1sim,veps0sim,Cost,vLambda,vW,W0new,W1new,vW0old,j,Emax;

	vW0=0;
	vW1=0;
	vW0new=0;
	vW1new=0;
	veps1sim=sigU1*rann(sim,1);
	veps0sim=sigU0*rann(sim,1);
	vLambda=0;
	vW =0;
	Emax=0;

	
	vW0old=W0old;
	Cost= BaC*A+ BeC*E;
	for (j=0; j<sim; ++j) 
	{
	vLambda= ranpoisson(1,1,BaL*A + BeL*E);  //Expected number of job offers
	vW= BaW*A + BeW*E + maxc(sigW*rann(vLambda,1)|-999999999);
	vW1=vW;

	Emax=Emax  + (maxc(((vW1-vW0old)~0)'))';
	}
	Emax=Emax/sim;
	//vY0=((1-delta)/(1-delta+PrS.*delta))*(oututil  +PrS.*(-CostS + (delta/(1-rho)).*EmaxS) +(1-PrS).*(-Cost + (rho/(1-rho)).*Emax));
	//vW0 = ((1-rho).*(1-PrS)./(1-rho+PrS.*rho)).*(oututil-Cost)  +	 (rho.*(1-PrS)./((1-rho).*(1-rho+PrS.*rho))).*Emax +  PrS.*WSres./(1-rho+PrS.*rho);
	//vW0 = (1-PrS).*(oututil-Cost  +	 (rho./(1-rho)).*Emax)  +  PrS.*WSres./(1-rho);
	vW0 = ((1-rho)./(1-rho.*(1-PrS))).*(oututil-Cost  +	 (rho./(1-rho)).*Emax) +  rho.*PrS.*WSres./(1-rho.*(1-PrS));
	
	W0new=vW0;
	
	return W0new;
}




V0s(W0old, param, A,E, oututil)	  //reservation offer after treatment
{
	/******************************/
 	decl rho, sigU0, sigU1, sigW, BaW,BeW, BdW , BaC,BeC, BdC, BaL,BeL, BdL ;

	rho=param[0];             //Discount rate such that 1/rho~=0.99
	sigU0=param[1];				//standard deviation of U0 random utility shock when no exit 
	sigU1=param[2];				//standard deviation of U1 random utility shock when exit 
	sigW=param[3];					//standard deviation of U0 w offer
	BaW=param[4];                  //ability parameter on w offer
	BeW=param[5];                  //effort parameter on w offer
	BdW=param[6];                  //treatment parameter on w offer
	BaC=param[7];                  //ability parameter on search cost
	BeC=param[8];                  //effort parameter on search cost
	BdC=param[9];                  //treatment parameter on search cost
	BaL=param[10];                  //ability parameter on offer rate lambda
	BeL=param[11];                  //effort parameter on offer	rate lambda
	BdL=param[12];                  //treatment parameter on offer rate lambda
	/******************************/	

	decl  vW0,vW1,vW0new,vW1new,veps1sim,veps0sim,Cost,vLambda,vW,W0new,V1new,vW0old,j,Emax;


	vW0=0;
	vW1=0;
	vW0new=0;
	vW1new=0;
	veps1sim=sigU1*rann(sim,1);
	veps0sim=sigU0*rann(sim,1);
	vLambda=0;
	vW =0;
	Emax=0;

	vW0old=W0old;
	Cost= BaC*A + BeC*E + BdC;
	for (j=0; j<sim; ++j) 
	{
	
	vLambda= ranpoisson(1,1,BaL*A + BeL*E + BdL);  //Expected number of job offers
	vW= BaW*A + BeW*E + BdW + maxc(sigW*rann(vLambda,1)|-999999999);
	vW1=vW;

	Emax=Emax  + (maxc(((vW1-vW0old)~0)'))';
	}
	Emax=Emax/sim;

	vW0=oututil -Cost + (rho/(1-rho)).*Emax;
	
	W0new=vW0;

	
	return W0new;
}


 
Exit(X,iTbar,param)
{		 
	
	/******************************/
	decl mX, obs, rho, sigU0, sigU1, sigW, BaW, BdW , BaC, BdC, BaL, BdL ;

	sigU0=param[1];				//standard deviation of U0 random utility shock when no exit 
	sigU1=param[2];				//standard deviation of U1 random utility shock when exit 
	mX=X;
	obs=sizer(mX);
	/******************************/
	
	decl  A,E, vOututil, oututil, i,time,iter,vWSres,WSold,WSnew,Vcrit,vWres,Wold,Wnew,PrS,WSres;

	//Generating terminal utility expectations and exit decision

	vOututil=mX[][6];

	vWSres=zeros(obs,1);
	vWres=zeros(obs,1);
	
	/////////////////////
	time = timer();
	//println(" i~durS~t+1~W-oututil~A~PrS =");
	
	for (i=0; i<obs; ++i)
	{
	A=mX[i][0];
	E=mX[i][1];
	oututil=mX[i][6];
	WSold=oututil;
	iter=0;
	Vcrit=100;

		while (Vcrit .> 0.01)		 //convergence of reservation value
		{
		iter=iter+1;
		
		//println("W =",W);
		WSnew=V0s(WSold, param, A,E, oututil) ;		 	 //This function generates the reservation offer w, not the reservation value (=w/(1-rho))
		
		Vcrit=fabs(WSold-WSnew);
		WSold=0.3*WSnew+0.7*WSold;
		
		
		//println("i~iter~Vcrit~VSold =",i~iter~Vcrit~VSold);	
		}
	println("i~iter~Vcrit~oututil~VSold =",i~iter~Vcrit~A~oututil~WSold);
	//println(" remaining minutes = ",(obs-i));
	//	print("time lapsed: ", timespan(time), "\n");
	vWSres[i]=WSold;	  //reservation offer after treatment
	
	Wold=oututil;
	iter=0;
	Vcrit=100;
	WSres=vWSres[i];
	PrS=mX[i][4];

		while (Vcrit .> 0.01)
		{
		iter=iter+1;
		
		Wnew=V0(Wold, param, A,E, oututil, WSres, PrS) ;	//This function generates the reservation offer w, not the reservation value (=w/(1-rho))

		Vcrit=fabs(Wold-Wnew);
		Wold=0.3*Wnew+0.7*Wold;
		
		
		//println("i~iter~Vcrit~Vold =",i~iter~Vcrit~Vold);	
		}

	println("i~iter~Vcrit~oututil~Vold =",i~iter~Vcrit~A~oututil~Wold);
	//println(" remaining minutes = ",(obs-i));
//	print("time lapsed: ", timespan(time), "\n");
    print("avg. minutes to completion: ", (((timer() - time)*(obs-i) / 6000)/(i+1)), "\n");
	
	vWres[i]=Wold;		//reservation offer before treatment
	//exit[-1];
	}

	return vWSres~vWres;
	
}

	


DGPexitInd(X,iTbar,param,vWSres,vWres,vWres0,popSim)
{

	/******************************/
 	decl  mX, obs, rho, sigU0, sigU1, sigW, BaW,BeW, BdW , BaC,BeC, BdC, BaL,BeL, BdL ;

	mX=X;
	obs=sizer(mX);

	rho=param[0];             //Discount rate such that 1/rho~=0.99
	sigU0=param[1];				//standard deviation of U0 random utility shock when no exit 
	sigU1=param[2];				//standard deviation of U1 random utility shock when exit 
	sigW=param[3];					//standard deviation of U0 w offer
	BaW=param[4];                  //ability parameter on w offer
	BeW=param[5];                  //effort parameter on w offer
	BdW=param[6];                  //treatment parameter on w offer
	BaC=param[7];                  //ability parameter on search cost
	BeC=param[8];                  //effort parameter on search cost
	BdC=param[9];                  //treatment parameter on search cost
	BaL=param[10];                  //ability parameter on offer	rate lambda
	BeL=param[11];                  //effort parameter on offer	rate lambda
	BdL=param[12];                  //treatment parameter on offer rate lambda
	/******************************/

	decl  vA,vE, vdurS,oututil,U0, U1, W, Cost, Lambda, t, i, mW,mIexit;
	
	vA=X[][0];
	vE=X[][1];
	vdurS=X[][5];
	oututil=X[][6];


	//Generating cost, lambda and W value outcomes for each period
	mW=zeros(obs,iTbar+1);
	Lambda=zeros(obs,iTbar);
	mIexit=zeros(obs,iTbar+1);
	
	for(t=0; t<iTbar; ++t)
	{


		
		if 	(popSim==3)
		{
			for (i=0; i<obs; ++i)
			{
				Lambda[i][t]= ranpoisson(1,1,BaL*vA[i] + BeL.*vE[i] + BdL.*(vdurS[i]-1 .<= t));	 ///realized number of job offers
				mW[i][t]= BaW.*vA[i] + BeW.*vE[i] + BdW.*(vdurS[i]-1 .<= t)+ maxc(sigW*rann(Lambda[i][t],1)|-999999999);	//realized W chosen from highest offer
			}
			/*** For  "DGPsample.m" and "DGPz0.m" population values   ***/
			mIexit[][t]=mW[][t].*(mW[][t].> vWres).*(vdurS-1 .>= t) + mW[][t].*(mW[][t].> vWSres).*(vdurS-1 .< t);	 
		}
		else
		{
			if(popSim==0)
			{
				for (i=0; i<obs; ++i)
				{
					Lambda[i][t]= ranpoisson(1,1,BaL*vA[i] + BeL.*vE[i] + BdL.*(vdurS[i]-1 .<= t));	 ///realized number of job offers
					mW[i][t]= BaW.*vA[i] + BeW.*vE[i] + maxc(sigW*rann(Lambda[i][t],1)|-999999999);	//realized W chosen from highest offer
				}
				/*** For DGPz0c.m  ex-ante population values ***/
				mIexit[][t]=mW[][t].*(mW[][t].> vWres) ;
			}
			else
			{
				for (i=0; i<obs; ++i)
					{
						Lambda[i][t]= ranpoisson(1,1,BaL*vA[i] + BeL.*vE[i] + BdL.*(vdurS[i]-1 .<= t));	 ///realized number of job offers
						mW[i][t]= BaW.*vA[i] + BeW.*vE[i] + BdW.*(vdurS[i]-1 .<= t)+ maxc(sigW*rann(Lambda[i][t],1)|-999999999);	//realized W chosen from highest offer
					}
					/*** For DGPz1.m  ex-post population values ***/
					mIexit[][t]=mW[][t].*(mW[][t].> vWres).*(vdurS-1 .>= t) + mW[][t].*(mW[][t].> vWSres).*(vdurS-1 .< t);
				
			}
		}								 
		
	  //println("t =",t);
	}

    //println("Cost =",Cost);
	//println("Lambda =",Lambda);
	//println("mW =",mW);
	
	mW=0;			  //to clear some of the memory
	Lambda=0;		  //to clear some of the memory
	return mIexit;
}
	   
durExit(obs,iTbar,mWexit)
{
	decl  i,j,vdurE,vW;

	vdurE=zeros(obs,1);
	vW=zeros(obs,1);
	
	for(i=0;i<obs;++i)
	{j=0;
        while (mWexit[i][j] .== 0)
        {   ++j;
			if (j ==iTbar)
			break;
		}
	vdurE[i]=j+1;
	vW[i]=mWexit[i][j];
	 }

	 return vdurE~vW;	   //return vector of potential treatment outcomes
}


	 	
main()
{
	decl iTbar,obs,nega,vA,vE,vZtilda,iZtilda,vZ,X,iPrSover,iPrSunder,vdurSstar,oututil,vPrS;
	decl param,rho,sigU0,sigU1,sigW,BaW,BeW,BdW, BaC,BeC, BdC, BaL,BeL, BdL, X0 ;

	/***Explanation of Parameter Calibration:
 		rho=0.99;
			Discount rate
		sigU0=3;
			Standard deviation of U0 random utility shock when no exit 
		sigU1=3;
			Standard deviation of U1 random utility shock when exit 
		sigW=3;
			Standard deviation of U0 w offer
		BaW=4;
			Ability parameter on w offer
		BeW=1;
			Effort parameter on w offer
		BdW=0;
			Treatment parameter on w offer
			=>calibrated for D=1 to have no effect on wages 
		BaC=0.2;
			Ability parameter on search cost
			=>calibrated such that costs are linearl functions of ability A
		BeC=0.1;
			Effort parameter on search cost
			=>calibrated such that costs are linearl functions of effort E
		BdC=0;
			Treatment parameter on search cost
			=>calibrated such that for D=1 costs increase by 0.5
		BaL=0.5/#d; #d=21 seems reasonable
			Ability parameter on offer rate lambda
			=>calibrated such that for A=1 get 1 offer every #d days on average & for A=6 get 6 offers every #d days
		BeL=0.1/#d; #d=21 seems reasonable
			Ability parameter on offer rate lambda
			=>calibrated such that for A=1 get 1 offer every #d days on average & for A=6 get 6 offers every #d days
		BdL=-1/#d; set to 0 for baseline
			Treatment parameter on offer rate lambda (negative treatment effect here)
			=>calibrated such that for D=1 get 1 offer less on average every #d days on average & for A=6 get 6 offers less every #d days
		iPrSover=0.03;
			Probability of treatment in each period if D>=Dtilda => Pr(S=s|S>=s, D>=Dtilda)
		iPrSunder=0;
			Probability of treatment in each period if D<Dtilda => Pr(S=s|S>=s, D<Dtilda)
			so Pr(S=s|D>=Dtilda)/Pr(S=s|D<Dtilda)=2


	Calibrating treatment:
		The idea in calibrating the treatment is to find parameters that induce the same avg change in exits.
		Of course, depending upon which paramter is chosen, the change in avg. exit duration may be due to very different
		processes. ex ante vs. ex post effects may affect different types in different ways.

		BdW=11 and BdC=-0.12 and BdL=1/21; both lead to avg reduction of about 14 days;

			
***/
	ranseed(3326);
	iTbar=5000;		 //potential end of being in initial state: star always represents potential outcomes			 
	obs=20000;			 //number of observations
	sim=1000;
	nega = 1; // If nega = 0 BdW=sdW, if nega = 1 BdW=-sdW 

	//obs=1000;			 //number of observations
	//sim=1000;
	
	vA=1+round(5*ranu(obs,1));		 //vector of abiltiy discrete uniformly distributed from [1;6]
	vE=1+round(2*ranu(obs,1));		 //vector of effort discrete uniformly distributed from [1;3]
	vZtilda=10*ranu(obs,1);				 //vector to create policy regime randomization
	iZtilda=5;						 //policy regime cutoff
	vZ=(vZtilda .>= iZtilda);		 //policy regime indicatior indicator
	X0=vA~vE~vZtilda~vZ;
	
	rho=0.995;             //Discount rate such that 1/rho~=0.99
	sigU0=3;				//standard deviation of U0 random utility shock when no exit 
	sigU1=3;				//standard deviation of U1 random utility shock when exit 
	sigW=3;					//standard deviation of U0 w offer
	BaW=4;                  //ability parameter on w offer
	BeW=0;                  //effort parameter on w offer
	BdW=0;                  //treatment parameter on w offer
	BaC=0.2;                //ability parameter on search cost
	BeC=0.1;                //effort parameter on search cost
	BdC=0;                  //treatment parameter on search cost	
	BaL=0.5/21;               //ability parameter on offer rate lambda  calibrated such that
	BeL=0.1/21;               //effort parameter on offer rate lambda  calibrated such that
	BdL=0;                  //treatment parameter on offer rate lambda

	/* Calibrating treatment effects */
	decl W,meanW,sdW,C,meanC,sdC,L,meanL,sdL;
	
	W=BaW.*vA + BeW.*vE + sigW.*rann(obs,1);
	C=BaC.*vA + BeC.*vE;
	L=BaL.*vA + BeL.*vE;
	oututil=0.75 .*W;	   //utility of outside option is 0.75 of expected w offer	
	meanW=sumc(W)/obs;	 meanC=sumc(C)/obs;	meanL=sumc(L)/obs;
	sdW=sumc(fabs(meanW-W))/obs	;	sdC=sumc(fabs(meanC-C))/obs	; 	sdL=sumc(fabs(meanL-L))/obs	;
	println("meanW~meanC~meanL =",meanW~meanC~meanL);	println("sdW~sdC~sdL =",sdW~sdC~sdL);


	decl mW,mWres,vWSres,vWres,mWexit,popSim,mdurE;
	 
	/***   Generating DGP sample values  ***/
	/***************************************/

	/*
	BdW=-sdW;			   //Take the treatment effect as one standard deviation of W  (with 10000 obs sdW=5.5827) 
	//BdC=-sdC;			   //Take the treatment effect as one standard deviation of C
	//BdL=-sdL/2;			   //Take the treatment effect as one standard deviation of L
	iPrSover=0.03;					 //Pr(S=s|S>=s, D>=Dtilda)
	iPrSunder=0;					 //Pr(S=s|S>=s, D<Dtilda)	  so Pr(S=s|D>=Dtilda)/Pr(S=s|D<Dtilda)=2
	vPrS= iPrSover .*(vZ .== 1) + iPrSunder .*(vZ .== 0);	 //probability of treatment

	param = rho  | sigU0  |  sigU1  | sigW   |  BaW  | BeW  |  BdW |  BaC  | BeC  |  BdC |  BaL  | BeL  |  BdL | iPrSover | iPrSunder;
	println("rho  | sigU0  |  sigU1  | sigW   |  BaW  | BeW  |  BdW |  BaC  | BeC  |  BdC |  BaL  | BeL  |  BdL | iPrSover | iPrSunder =",param);
		
	vdurSstar=dgpS(obs,vPrS,iTbar);	   //generate potential training outcome svalues between [1,iTbar+1]
	//println("vdurSstar =",sortc(vdurSstar));

	X=X0~vPrS~vdurSstar~oututil;
	//println("X =",X);

	
	  
	/***Exit(X,iTbar,param) generates exit outcomes***/
	decl Xexit,vdurE,vW,vWSres0;
	
    mWres=Exit(X,iTbar,param);
	//mWres=loadmat("DGPongTyAmWresDsdW1p.m");
	vWSres=mWres[][0];			 //reservation offer after treatment
	vWres=mWres[][1];			//reservation offer before treatment
	
	vWSres0=zeros(obs,1);
	popSim=3;                   // This value is irrelvent for the DGP sample
	mWexit=DGPexitInd(X,iTbar,param,vWSres,vWres,vWSres0,popSim);

	mdurE = durExit(obs,iTbar,mWexit) ;
	vdurE=mdurE[][0];			 // Exit durations
	vW=mdurE[][1];			// wages at Exit
	
	X=X~vdurE~vW;
	 println("X =",X);
	//println("mWexit =",mWexit);

	/* Save results */
	//savemat("DGPsample_mWres.m",mWres);		// Matrix of reservation wages	vWSres~vWres    
	//savemat("DGPsample_param.m",param);	// vector of parameter values
	savemat("DGPsample.m",X); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW  note: vZtilda is pointless

	*/

	/***   Generating DGP sample values  when exclusion restriction holds ***/
	/************************************************************************/
	decl Xexit,vdurE,vW,vWSres0;
	BdW=sdW;			   //Take the treatment effect as one standard deviation of W  (with 10000 obs sdW=5.5827)
	if 	(nega==1)
	{
		BdW=-sdW;
	}
	//BdC=-sdC;			   //Take the treatment effect as one standard deviation of C
	//BdL=-sdL/2;			   //Take the treatment effect as one standard deviation of L
	iPrSover=0.01;					 //Pr(S=s|S>=s, D>=Dtilda)
	iPrSunder=0.03;					 //Pr(S=s|S>=s, D<Dtilda)	  so Pr(S=s|D>=Dtilda)/Pr(S=s|D<Dtilda)=2
	vPrS= iPrSover .*(vZ .== 1) + iPrSunder .*(vZ .== 0);	 //probability of treatment

	param = rho  | sigU0  |  sigU1  | sigW   |  BaW  | BeW  |  BdW |  BaC  | BeC  |  BdC |  BaL  | BeL  |  BdL | iPrSover | iPrSunder;
	println("rho  | sigU0  |  sigU1  | sigW   |  BaW  | BeW  |  BdW |  BaC  | BeC  |  BdC |  BaL  | BeL  |  BdL | iPrSover | iPrSunder =",param);
		
	vdurSstar=dgpS(obs,vPrS,iTbar);	   //generate potential training outcome svalues between [1,iTbar+1]
	//println("vdurSstar =",sortc(vdurSstar));

	X=X0~vPrS~vdurSstar~oututil;
	//println("X =",X);


	  
	/***Exit(X,iTbar,param) generates exit outcomes***/

	
    mWres=Exit(X,iTbar,param);
	//mWres=loadmat("DGPongTyAmWresDsdW1p.m");
	vWSres=mWres[][0];			 //reservation offer after treatment
	vWres=mWres[][1];			//reservation offer before treatment
	
	vWSres0=zeros(obs,1);
	popSim=3;                   // This value is irrelvent for the DGP sample
	mWexit=DGPexitInd(X,iTbar,param,vWSres,vWres,vWSres0,popSim);

	mdurE = durExit(obs,iTbar,mWexit) ;
	vdurE=mdurE[][0];			 // Exit durations
	vW=mdurE[][1];			// wages at Exit
	
	X=X~vdurE~vW;
	 println("X =",X);
	//println("mWexit =",mWexit);

	/* Save results when exclusion restriction holds*/
	//savemat("DGPsample_mWresER.m",mWres);		// Matrix of reservation wages	vWSres~vWres    
	//savemat("DGPsample_param.m",param);	// vector of parameter values
	if 	(nega==0)
	{
		savemat("DGPsampleER.m",X); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW  note: vZtilda is pointless
	}
	else
	{
		savemat("DGPsampleER_min.m",X); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW  note: vZtilda is pointless
	}
	
	

	
	/***   Generating DGP population values for regime effects Z=0 (so PrS=0) potential outcomes ***/
	/************************************************************************************************/
	/*
	BdW=0;			   // Set to 0 	to obtain reservation wage after treatment given no effect of treatment (for later below)
	//BdC=-sdC;			   //Take the treatment effect as one standard deviation of C
	//BdL=-sdL/2;			   //Take the treatment effect as one standard deviation of L
	iPrSover=0;					 //Pr(S=s|S>=s, D>=Dtilda)
	iPrSunder=0;					 //Pr(S=s|S>=s, D<Dtilda)	  so Pr(S=s|D>=Dtilda)/Pr(S=s|D<Dtilda)=2
	vPrS= iPrSover .*(vZ .== 1) + iPrSunder .*(vZ .== 0);	 //probability of treatment

	param = rho  | sigU0  |  sigU1  | sigW   |  BaW  | BeW  |  BdW |  BaC  | BeC  |  BdC |  BaL  | BeL  |  BdL | iPrSover | iPrSunder;
	println("rho  | sigU0  |  sigU1  | sigW   |  BaW  | BeW  |  BdW |  BaC  | BeC  |  BdC |  BaL  | BeL  |  BdL | iPrSover | iPrSunder =",param);
		
	vdurSstar=dgpS(obs,vPrS,iTbar);	   //generate potential training outcome svalues between [1,iTbar+1]
	//println("vdurSstar =",sortc(vdurSstar));

	X=X0~vPrS~vdurSstar~oututil;
	//println("X =",X);


	/***Exit(X,iTbar,param) generates exit outcomes***/
    mWres=Exit(X,iTbar,param);
	//mWres=loadmat("DGPongTyAmWresDsdW1p.m");
	vWSres=mWres[][0];			 //reservation offer after treatment	             
	vWres=mWres[][1];			//reservation offer before treatment

	/***   Generate Z=0 population values with no anticipation and no treatment   ***/
	vWSres0=zeros(obs,1);
	popSim=3;                     // This value is irrelvent value here
	mWexit=DGPexitInd(X,iTbar,param,vWSres,vWres,vWSres0,popSim);
	vWSres0=vWSres;  // This will be used in next simulation below

	mdurE = durExit(obs,iTbar,mWexit) ;
	vdurE=mdurE[][0];			 // Exit durations
	vW=mdurE[][1];			// wages at Exit
	
	X=X~vdurE~vW;
	println("X =",X);
	//println("mWexit =",mWexit);

	/* Save results */
	//savemat("DGPz0_mWres.m",mWres);		// Matrix of reservation wages	vWSres~vWres    
	//savemat("DGPz0_param.m",param);	// vector of parameter values
	savemat("DGPz0.m",X); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW

	 */
		

		  
	/***   Generating DGP population values for Z=1 (so PrS=0.01) regime and treatment potential outcomes   ***/
	/*********************************************************************************************************/
	BdW=sdW;			   //Take the treatment effect as one standard deviation of W  (with 10000 obs sdW=5.5827)
	if 	(nega==1)
	{
		BdW=-sdW;
	}
	//BdC=-sdC;			   //Take the treatment effect as one standard deviation of C
	//BdL=-sdL/2;			   //Take the treatment effect as one standard deviation of L
	iPrSover=0.01;					 //Pr(S=s|S>=s, D>=Dtilda)
	iPrSunder=0.01;					 //Pr(S=s|S>=s, D<Dtilda)	  so Pr(S=s|D>=Dtilda)/Pr(S=s|D<Dtilda)=2
	vPrS= iPrSover .*(vZ .== 1) + iPrSunder .*(vZ .== 0);	 //probability of treatment

	param = rho  | sigU0  |  sigU1  | sigW   |  BaW  | BeW  |  BdW |  BaC  | BeC  |  BdC |  BaL  | BeL  |  BdL | iPrSover | iPrSunder;
	println("rho  | sigU0  |  sigU1  | sigW   |  BaW  | BeW  |  BdW |  BaC  | BeC  |  BdC |  BaL  | BeL  |  BdL | iPrSover | iPrSunder =",param);
		
	vdurSstar=dgpS(obs,vPrS,iTbar);	   //generate potential training outcome svalues between [1,iTbar+1]
	//println("vdurSstar =",sortc(vdurSstar));

	X=X0~vPrS~vdurSstar~oututil;
	//println("X =",X);

	/***Exit(X,iTbar,param) generates exit outcomes***/
    mWres=Exit(X,iTbar,param);
	//mWres=loadmat("DGPongTyAmWresDsdW1p.m");
	vWSres=mWres[][0];			 //reservation offer after treatment
	vWres=mWres[][1];			//reservation offer before treatment

	/***   Generate Z=1 population values with anticipation but no entry into treatment   ***/
	popSim=0;                   
	mWexit=DGPexitInd(X,iTbar,param,vWSres,vWres,vWSres0,popSim);
	//vWSres0=vWSres;  // This will be used in next simulation below

	mdurE = durExit(obs,iTbar,mWexit) ;
	vdurE=mdurE[][0];			 // Exit durations
	vW=mdurE[][1];			// wages at Exit
	decl  Xz0c;
	Xz0c=X~vdurE~vW;
	println("Xz0c =",Xz0c);
	//println("mWexit =",mWexit);

	/* Save results */
	//savemat("DGPz1c_mWres.m",mWres);		// Matrix of reservation wages	vWSres~vWres    
	//savemat("DGPz1_param.m",param);	// vector of parameter values
	
	if 	(nega==0)
	{
		savemat("DGPz1c.m",Xz0c); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW
	}
	else
	{
		savemat("DGPz1c_min.m",Xz0c); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW
	}
	/***   Generate Z=1 population values with anticipation of treatment and effect of treatment after you enter treatment  ***/
	popSim=1;                   
	mWexit=DGPexitInd(X,iTbar,param,vWSres,vWres,vWSres0,popSim);

	mdurE = durExit(obs,iTbar,mWexit) ;
	vdurE=mdurE[][0];			 // Exit durations
	vW=mdurE[][1];			// wages at Exit
	decl  Xz1;
	Xz1=X~vdurE~vW;
	println("Xz1 =",Xz1);

	/* Save results */
	//savemat("DGPz1S_mWres.m",mWres);		// Matrix of reservation wages	vWSres~vWres    
	//savemat("DGPz1_param.m",param);	// vector of parameter values
	
	if 	(nega==0)
	{
		savemat("DGPz1S.m",Xz1); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW
	}
	else
	{
		savemat("DGPz1S_min.m",Xz1); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW
	}
	  


		

 /***   Generating DGP population values for Z=0 (so PrS=0.03) regime and treatment potential outcomes  when exclusion restriction holds ***/
	/*********************************************************************************************************/
	BdW=sdW;			   //Take the treatment effect as one standard deviation of W  (with 10000 obs sdW=5.5827)
	if 	(nega==1)
	{
		BdW=-sdW;
	}
	//BdC=-sdC;			   //Take the treatment effect as one standard deviation of C
	//BdL=-sdL/2;			   //Take the treatment effect as one standard deviation of L
	iPrSover=0.03;					 //Pr(S=s|S>=s, D>=Dtilda)
	iPrSunder=0.03;					 //Pr(S=s|S>=s, D<Dtilda)	  so Pr(S=s|D>=Dtilda)/Pr(S=s|D<Dtilda)=2
	vPrS= iPrSover .*(vZ .== 1) + iPrSunder .*(vZ .== 0);	 //probability of treatment

	param = rho  | sigU0  |  sigU1  | sigW   |  BaW  | BeW  |  BdW |  BaC  | BeC  |  BdC |  BaL  | BeL  |  BdL | iPrSover | iPrSunder;
	println("rho  | sigU0  |  sigU1  | sigW   |  BaW  | BeW  |  BdW |  BaC  | BeC  |  BdC |  BaL  | BeL  |  BdL | iPrSover | iPrSunder =",param);
		
	vdurSstar=dgpS(obs,vPrS,iTbar);	   //generate potential training outcome svalues between [1,iTbar+1]
	//println("vdurSstar =",sortc(vdurSstar));

	X=X0~vPrS~vdurSstar~oututil;
	//println("X =",X);

	/***Exit(X,iTbar,param) generates exit outcomes***/
    mWres=Exit(X,iTbar,param);
	//mWres=loadmat("DGPongTyAmWresDsdW1p.m");
	vWSres=mWres[][0];			 //reservation offer after treatment
	vWres=mWres[][1];			//reservation offer before treatment

	/***   Generate Z=0 population values with anticipation but no entry into treatment   ***/
	popSim=0;                   
	mWexit=DGPexitInd(X,iTbar,param,vWSres,vWres,vWSres0,popSim);
	//vWSres0=vWSres;  // This will be used in next simulation below
	
	mdurE = durExit(obs,iTbar,mWexit) ;
	vdurE=mdurE[][0];			 // Exit durations
	vW=mdurE[][1];			// wages at Exit

	Xz0c=X~vdurE~vW;
	println("Xz0c =",Xz0c);
	//println("mWexit =",mWexit);

	/* Save results when exclusion restriction hold */
	//savemat("DGPz0c_mWresER.m",mWres);		// Matrix of reservation wages	vWSres~vWres    
	//savemat("DGPz1_param.m",param);	// vector of parameter values
	
	if 	(nega==0)
	{
		savemat("DGPz0cER.m",Xz0c); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW
	}
	else
	{
		savemat("DGPz0cER_min.m",Xz0c); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW
	}
	  

	 
	/***   Generate Z=0 population values with anticipation of treatment and effect of treatment after you enter treatment  ***/
	popSim=1;                   
	mWexit=DGPexitInd(X,iTbar,param,vWSres,vWres,vWSres0,popSim);

	mdurE = durExit(obs,iTbar,mWexit) ;
	vdurE=mdurE[][0];			 // Exit durations
	vW=mdurE[][1];			// wages at Exit

	Xz1=X~vdurE~vW;
	println("Xz1 =",Xz1);

	/* Save results when exclusion restriction hold */
	//savemat("DGPz0S_mWresER.m",mWres);		// Matrix of reservation wages	vWSres~vWres    
	//savemat("DGPz1_param.m",param);	// vector of parameter values
	
	if 	(nega==0)
	{
		savemat("DGPz0SER.m",Xz1); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW
	}
	else
	{
		savemat("DGPz0SER_min.m",Xz1); //vA~vE~vZtilda~vZ~vPrS~vdurSstar~oututil~vdurE~vW
	}
	
	
	 
	  

	
}
